@@ -9,18 +9,21 @@ class RubyTemplate(string.Template):
 
 SOURCE_FILE_GRAMMAR = """
 SourceFileTraceabilityInfo[noskipws]:
-    (SingleLineString | pragmas += RangePragma)*
+    ((pragmas += RangePragma) | SingleLineString)*
 ;
 
 RangePragma[noskipws]:
-  /.*STRICTDOC / (pragma_type = 'RANGE') ' ' (begin_or_end = 'BEGIN' | begin_or_end = 'END') ': ' (reqs += Req[', ']) '\n'
+  /.*SDOC/
+  (begin_or_end = '>' | begin_or_end = '<')
+  ' '
+  (reqs_objs += Req[', ']) '\n'?
 ;
 
 Req[noskipws]:
-  /[A-Za-z][A-Z0-9-]+/
+  uid = /[A-Za-z][A-Z0-9-]+/
 ;
 
 SingleLineString[noskipws]:
-  /(?!.*STRICTDOC RANGE).*/ '\n'
+  /(?!.*SDOC[><]).*/ '\n'?
 ;
 """
