@@ -10,7 +10,7 @@ def _check_formats(formats):
         if fmt in EXPORT_FORMATS:
             continue
         message = "invalid choice: '{}' (choose from {})".format(
-            fmt, ", ".join(map(lambda f: "'{}'".format(f), EXPORT_FORMATS))
+            fmt, ", ".join(map(lambda f: f"'{f}'", EXPORT_FORMATS))
         )
         raise argparse.ArgumentTypeError(message)
     return formats_array
@@ -46,7 +46,10 @@ def cli_args_parser() -> argparse.ArgumentParser:
         "export",
         help="Export document tree.",
         parents=[],
-        description="Export command: input SDoc documents are generated into HTML and other formats.",
+        description=(
+            "Export command: "
+            "input SDoc documents are generated into HTML and other formats."
+        ),
     )
     command_parser_export.add_argument(
         "input_paths",
@@ -72,12 +75,24 @@ def cli_args_parser() -> argparse.ArgumentParser:
     command_parser_export.add_argument(
         "--no-parallelization",
         action="store_true",
-        help="Disables parallelization. All work happens in the main thread. This option might be useful for debugging.",
+        help=(
+            "Disables parallelization. All work happens in the main thread. "
+            "This option might be useful for debugging."
+        ),
+    )
+    command_parser_export.add_argument(
+        "--enable-mathjax",
+        action="store_true",
+        help=("Enables Mathjax support (only HTML export)."),
     )
     command_parser_export.add_argument(
         "--experimental-enable-file-traceability",
         action="store_true",
-        help="Experimental feature: enables traceability between requirements and files (warning: implementation is not complete).",
+        help=(
+            "Experimental feature: "
+            "enables traceability between requirements and files "
+            "(warning: implementation is not complete)."
+        ),
     )
 
     command_parser_passthrough = command_subparsers.add_parser(
@@ -109,6 +124,7 @@ class ExportCommandConfig:
         formats,
         fields,
         no_parallelization,
+        enable_mathjax,
         experimental_enable_file_traceability,
     ):
         self.strictdoc_root_path = strictdoc_root_path
@@ -117,6 +133,7 @@ class ExportCommandConfig:
         self.formats = formats
         self.fields = fields
         self.no_parallelization = no_parallelization
+        self.enable_mathjax = enable_mathjax
         self.experimental_enable_file_traceability = (
             experimental_enable_file_traceability
         )
@@ -147,6 +164,7 @@ class SDocArgsParser:
             self.args.formats,
             self.args.fields,
             self.args.no_parallelization,
+            self.args.enable_mathjax,
             self.args.experimental_enable_file_traceability,
         )
 
