@@ -4,12 +4,14 @@ class DocumentMeta:
         level,
         document_filename_base,
         input_doc_full_path,
+        input_doc_dir_rel_path,
         output_document_dir_full_path,
         output_document_dir_rel_path,
     ):
         self.level = level
         self.document_filename_base = document_filename_base
         self.input_doc_full_path = input_doc_full_path
+        self.input_doc_rel_path = input_doc_dir_rel_path
         self.output_document_dir_full_path = output_document_dir_full_path
         self.output_document_dir_rel_path = output_document_dir_rel_path
 
