@@ -15,13 +15,18 @@ class LinkRenderer:
     def render_local_anchor(self, node):
         if node in self.local_anchor_cache:
             return self.local_anchor_cache[node]
+        unique_prefix = node.context.title_number_string
         if isinstance(node, Section):
-            local_anchor = self._string_to_link(node.title)
+            local_anchor = f"{unique_prefix}-{self._string_to_link(node.title)}"
         elif isinstance(node, Requirement):
             if node.uid and len(node.uid) > 0:
-                local_anchor = self._string_to_link(node.uid)
+                local_anchor = (
+                    f"{unique_prefix}-{self._string_to_link(node.uid)}"
+                )
             elif node.title and len(node.title) > 0:
-                local_anchor = self._string_to_link(node.title)
+                local_anchor = (
+                    f"{unique_prefix}-{self._string_to_link(node.title)}"
+                )
             else:
                 # TODO: This is not reliable
                 local_anchor = str(id(node))
@@ -70,16 +75,57 @@ class LinkRenderer:
         self.req_link_cache[link_cache_key][node] = requirement_link
         return requirement_link
 
+    @staticmethod
     def render_source_file_link(
-        self, requirement: Requirement, source_file_link: str
+        requirement: Requirement, source_file_link: str
     ):
         document: Document = requirement.ng_document_reference.get_document()
         path_prefix = document.meta.get_root_path_prefix()
-        source_file_link = f"{path_prefix}/_source_files/{document.meta.output_document_dir_rel_path}/{source_file_link}.html"
+        source_file_link = (
+            f"{path_prefix}"
+            f"/_source_files"
+            f"/{document.meta.output_document_dir_rel_path}"
+            f"/{source_file_link}.html"
+        )
         return source_file_link
 
+    @staticmethod
+    def render_source_file_link_from_root(
+        requirement: Requirement, source_file_link: str
+    ):
+        document: Document = requirement.ng_document_reference.get_document()
+        source_file_link = (
+            f"_source_files"
+            f"/{document.meta.output_document_dir_rel_path}"
+            f"/{source_file_link}.html"
+        )
+        return source_file_link
+
+    @staticmethod
+    def render_source_file_link_from_root_2(source_file: SourceFile):
+        assert isinstance(source_file, SourceFile)
+        source_file_link = (
+            f"_source_files"
+            f"/{source_file.doctree_root_mount_path}"
+            f"/{source_file.in_doctree_source_file_rel_path}.html"
+        )
+        return source_file_link
+
+    @staticmethod
+    def render_source_file_link_from_source_file(
+        requirement: Requirement, source_file_link: str
+    ):
+        document: Document = requirement.ng_document_reference.get_document()
+        path_prefix = document.meta.get_root_path_prefix()
+        source_file_link = (
+            f"{path_prefix}"
+            f"/{document.meta.output_document_dir_rel_path}"
+            f"/{source_file_link}.html#"
+        )
+        return source_file_link
+
+    @staticmethod
     def render_requirement_in_source_file_link(
-        self,
         requirement: Requirement,
         source_link: str,
         context_source_file: SourceFile,
@@ -93,12 +139,17 @@ class LinkRenderer:
             return ("../" * level)[:-1]
 
         path_prefix = get_root_path_prefix(context_source_file.level + 2)
-        source_file_link = f"{path_prefix}/_source_files/{context_source_file.doctree_root_mount_path}/{source_link}.html#{requirement.uid}"
+        source_file_link = (
+            f"{path_prefix}"
+            f"/_source_files"
+            f"/{context_source_file.doctree_root_mount_path}"
+            f"/{source_link}.html#{requirement.uid}"
+        )
         return source_file_link
 
-    def render_requirement_in_source_file_range_link(
-        self,
-        requirement: Requirement,
+    @staticmethod
+    def render_requirement_in_source_file_range_link_using_id(
+        req_uid: str,
         source_link: str,
         context_source_file: SourceFile,
         range,
@@ -112,10 +163,26 @@ class LinkRenderer:
             return ("../" * level)[:-1]
 
         path_prefix = get_root_path_prefix(context_source_file.level + 2)
-        # source_file_link = f"{path_prefix}/_source_files/{context_source_file.doctree_root_mount_path}/{source_link}.html?begin={range.ng_source_line_begin}&end={range.ng_source_line_end}#{requirement.uid}"
-        source_file_link = f"{path_prefix}/_source_files/{context_source_file.doctree_root_mount_path}/{source_link}.html#{requirement.uid}:{range.ng_source_line_begin}:{range.ng_source_line_end}"
+        source_file_link = (
+            f"{path_prefix}"
+            f"/_source_files"
+            f"/{context_source_file.doctree_root_mount_path}"
+            f"/{source_link}.html"
+            f"#{req_uid}#{range.ng_range_line_begin}#{range.ng_range_line_end}"
+        )
         return source_file_link
 
+    def render_requirement_in_source_file_range_link(
+        self,
+        requirement: Requirement,
+        source_link: str,
+        context_source_file: SourceFile,
+        range,
+    ):
+        return self.render_requirement_in_source_file_range_link_using_id(
+            requirement.uid, source_link, context_source_file, range
+        )
+
     @staticmethod
     def _string_to_link(string):
         return re.sub(r"[^\w0-9]+", "-", string)
